Modify baseline values due to vector control
Source:R/bednet-effect_sizes-lemenach.R
compute_bednet_effect_sizes_lemenach.RdImplements Bed_Net_Effect_Sizes for the Le Menach ITN model of vector control
Usage
compute_bednet_effect_sizes_lemenach(
ix,
phi,
ff,
qq,
gg,
tau0_frac = c(0.68/3, 2.32/3),
rr = 0.56,
ss = 0.03
)Arguments
- ix
an index over nPatches
- phi
ITN coverage
- ff
baseline blood feeding rate
baseline human fraction
- gg
baseline mosquito mortality rate
- tau0_frac
a numeric vector giving the proportion of a feeding cycle spent host seeking/bloodfeeding vs. resting/oviposition
- rr
probability of mosquito being repelled upon contact with ITN
- ss
probability of mosquito successfully feeding upon contact with ITN